summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CMakeLists.txt2
-rw-r--r--doc/de/user/plugins.de.xml2
-rw-r--r--doc/en/user/plugins.en.xml2
-rw-r--r--po/cs.po6
-rw-r--r--po/de.po6
-rw-r--r--po/es.po6
-rw-r--r--po/fr.po8
-rw-r--r--po/hu.po6
-rw-r--r--po/pl.po6
-rw-r--r--po/ru.po6
-rw-r--r--po/weechat.pot6
-rw-r--r--src/plugins/xfer/xfer-dcc.c2
-rw-r--r--src/plugins/xfer/xfer-network.c2
-rw-r--r--src/plugins/xfer/xfer.c8
-rw-r--r--src/plugins/xfer/xfer.h2
15 files changed, 35 insertions, 35 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 653ef92a7..42405db1d 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -58,7 +58,7 @@ OPTION(DISABLE_RUBY "Disable Ruby scripting language")
OPTION(DISABLE_LUA "Disable Lua scripting language")
OPTION(DISABLE_TCL "Disable Tcl scripting language")
OPTION(ENABLE_TRIGGER "Enable Trigger plugin")
-OPTION(DISABLE_XFER "Disable Xfer (file transfert) plugin")
+OPTION(DISABLE_XFER "Disable Xfer plugin (file transfer and direct chat)")
OPTION(DISABLE_DOC "Disable Doc")
ADD_SUBDIRECTORY( po )
diff --git a/doc/de/user/plugins.de.xml b/doc/de/user/plugins.de.xml
index e182a15fe..9d8f6c543 100644
--- a/doc/de/user/plugins.de.xml
+++ b/doc/de/user/plugins.de.xml
@@ -119,7 +119,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
<para>tcl: Tcl scripting API</para>
</listitem>
<listitem>
- <para>xfer: file transfert and direct chat</para>
+ <para>xfer: file transfer and direct chat</para>
</listitem>
</itemizedlist>
</para>
diff --git a/doc/en/user/plugins.en.xml b/doc/en/user/plugins.en.xml
index 312ede09b..b2e57a84a 100644
--- a/doc/en/user/plugins.en.xml
+++ b/doc/en/user/plugins.en.xml
@@ -118,7 +118,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
<para>tcl: Tcl scripting API</para>
</listitem>
<listitem>
- <para>xfer: file transfert and direct chat</para>
+ <para>xfer: file transfer and direct chat</para>
</listitem>
</itemizedlist>
</para>
diff --git a/po/cs.po b/po/cs.po
index 7b37c2429..75a4fb847 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: 2009-05-11 13:02+0200\n"
"Last-Translator: Jiri Golembiovsky <golemj@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -5494,7 +5494,7 @@ msgstr "%s nedostatek paměti pro infobar zprávu\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
"%s nemohu obnovit soubor \"%s\" (port: %d, počáteční pozice: %u): DCC "
"nenalezeno nebo ukončeno\n"
@@ -5506,7 +5506,7 @@ msgstr "DCC: soubor %s%s%s bude obnoven na pozici %u\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
"%s nemohu obnovit soubor \"%s\" (port: %d, počáteční pozice: %u): DCC "
"nenalezeno nebo ukončeno\n"
diff --git a/po/de.po b/po/de.po
index 9e19c6214..d4de55334 100644
--- a/po/de.po
+++ b/po/de.po
@@ -9,7 +9,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: 2009-05-11 13:02+0200\n"
"Last-Translator: Thomas Schuetz <i18n@internet-villa.de>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -5439,7 +5439,7 @@ msgstr "%s nicht genügend Speicher für Infobar-Nachricht\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
"%s kann die Datei \"%s\" nicht fortsetzen (Port: %d, Startposition: %u): DCC "
"nicht gefunden oder bereits fertig\n"
@@ -5451,7 +5451,7 @@ msgstr "DCC: Datei %s%s%s wird an Position %u fortgesetzt\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
"%s kann die Datei \"%s\" nicht fortsetzen (Port: %d, Startposition: %u): DCC "
"nicht gefunden oder bereits fertig\n"
diff --git a/po/es.po b/po/es.po
index fa73a82f5..b9f3045c8 100644
--- a/po/es.po
+++ b/po/es.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: 2009-05-11 13:02+0200\n"
"Last-Translator: Roberto González Cardenete <robert.glez@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -5428,7 +5428,7 @@ msgstr ""
#, fuzzy, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
"%s no puede reanudar el archivo \"%s\" (puerto: %d, posición de inicio: %"
"u): DCC no encontrado o terminado\n"
@@ -5440,7 +5440,7 @@ msgstr "DCC: archivo %s%s%s reanudado en la posición %u\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
"%s no puede reanudar el archivo \"%s\" (puerto: %d, posición de inicio: %"
"u): DCC no encontrado o terminado\n"
diff --git a/po/fr.po b/po/fr.po
index a18c603fa..66b565b3c 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -6,8 +6,8 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
-"PO-Revision-Date: 2009-05-11 13:02+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
+"PO-Revision-Date: 2009-05-12 11:27+0200\n"
"Last-Translator: FlashCode <flashcode@flashtux.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
"MIME-Version: 1.0\n"
@@ -5608,7 +5608,7 @@ msgstr "%s%s: erreur de création du xfer"
#, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
"%s%s: impossible de continuer le fichier \"%s\" (port: %d, position de "
"départ: %lu): xfer non trouvé ou non prêt pour le transfert"
@@ -5620,7 +5620,7 @@ msgstr "%s: fichier %s sera recommencé en position %lu"
#, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
"%s%s: impossible d'accepter de continuer le fichier \"%s\" (port: %d, "
"position de départ: %lu): xfer non trouvé ou non prêt pour le transfert"
diff --git a/po/hu.po b/po/hu.po
index c1a4204dc..b9e3a1989 100644
--- a/po/hu.po
+++ b/po/hu.po
@@ -12,7 +12,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: 2009-05-11 13:02+0200\n"
"Last-Translator: Andras Voroskoi <voroskoi@frugalware.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -5494,7 +5494,7 @@ msgstr "%s nincs elég memória az információs pult üzenethez\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
"%s nem sikerült a(z) \"%s\" fájlra visszatérni (port: %d, indulási pozíció: %"
"u): DCC nem található vagy véget ért\n"
@@ -5506,7 +5506,7 @@ msgstr "DCC: a(z) %s%s%s fájl visszatért a(z) %u pozíción\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
"%s nem sikerült a(z) \"%s\" fájlra visszatérni (port: %d, indulási pozíció: %"
"u): DCC nem található vagy véget ért\n"
diff --git a/po/pl.po b/po/pl.po
index 4afbce72b..a7ad4e07a 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -9,7 +9,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: 2009-05-11 13:02+0200\n"
"Last-Translator: <soltys@szluug.org>\n"
"Language-Team: Polish\n"
@@ -4769,7 +4769,7 @@ msgstr ""
#, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
#, c-format
@@ -4779,7 +4779,7 @@ msgstr ""
#, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
#, c-format
diff --git a/po/ru.po b/po/ru.po
index 6d215787a..3120c7943 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.3.0-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: 2009-05-11 13:02+0200\n"
"Last-Translator: Pavel Shevchuk <stlwrt@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -5464,7 +5464,7 @@ msgstr "%s недостаточно памяти для сообщения в с
#, fuzzy, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
"%s не могу продолжить файл \"%s\" (порт: %d, начальная позиция: %u): DCC не "
"найден или завершён\n"
@@ -5476,7 +5476,7 @@ msgstr "DCC: файл %s%s%s продолжается с позиции %u\n"
#, fuzzy, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
"%s не могу продолжить файл \"%s\" (порт: %d, начальная позиция: %u): DCC не "
"найден или завершён\n"
diff --git a/po/weechat.pot b/po/weechat.pot
index 0279a9875..356460e4a 100644
--- a/po/weechat.pot
+++ b/po/weechat.pot
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2009-05-11 12:44+0200\n"
+"POT-Creation-Date: 2009-05-12 11:26+0200\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
@@ -4732,7 +4732,7 @@ msgstr ""
#, c-format
msgid ""
"%s%s: unable to resume file \"%s\" (port: %d, start position: %lu): xfer not "
-"found or not ready for transfert"
+"found or not ready for transfer"
msgstr ""
#, c-format
@@ -4742,7 +4742,7 @@ msgstr ""
#, c-format
msgid ""
"%s%s: unable to accept resume file \"%s\" (port: %d, start position: %lu): "
-"xfer not found or not ready for transfert"
+"xfer not found or not ready for transfer"
msgstr ""
#, c-format
diff --git a/src/plugins/xfer/xfer-dcc.c b/src/plugins/xfer/xfer-dcc.c
index 666602dca..9d4ca98db 100644
--- a/src/plugins/xfer/xfer-dcc.c
+++ b/src/plugins/xfer/xfer-dcc.c
@@ -16,7 +16,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-/* xfer-dcc.c: file transfert via DCC protocol */
+/* xfer-dcc.c: file transfer via DCC protocol */
#include <stdlib.h>
diff --git a/src/plugins/xfer/xfer-network.c b/src/plugins/xfer/xfer-network.c
index 948b52b2e..d5e643016 100644
--- a/src/plugins/xfer/xfer-network.c
+++ b/src/plugins/xfer/xfer-network.c
@@ -148,7 +148,7 @@ xfer_network_child_read_cb (void *arg_xfer, int fd)
case XFER_STATUS_ACTIVE:
if (xfer->status == XFER_STATUS_CONNECTING)
{
- /* connection was successful by child, init transfert times */
+ /* connection was successful by child, init transfer times */
xfer->status = XFER_STATUS_ACTIVE;
xfer->start_transfer = time (NULL);
xfer->last_check_time = time (NULL);
diff --git a/src/plugins/xfer/xfer.h b/src/plugins/xfer/xfer.h
index ba973223a..e17bfc7e8 100644
--- a/src/plugins/xfer/xfer.h
+++ b/src/plugins/xfer/xfer.h
@@ -35,7 +35,7 @@ enum t_xfer_type
XFER_NUM_TYPES,
};
-/* xfer protocol (for file transfert) */
+/* xfer protocol (for file transfer) */
enum t_xfer_protocol
{
diff --git a/src/plugins/xfer/xfer.c b/src/plugins/xfer/xfer.c
index 2ea59bdc5..8ebd638fc 100644
--- a/src/plugins/xfer/xfer.c
+++ b/src/plugins/xfer/xfer.c
@@ -16,7 +16,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
/* xfer.c: file transfert and direct chat plugin for WeeChat */
#include <stdlib.h>
@@ -43,7 +43,7 @@
WEECHAT_PLUGIN_NAME(XFER_PLUGIN_NAME);
-WEECHAT_PLUGIN_DESCRIPTION("Xfer (file transfert and direct chat) plugin for "
+WEECHAT_PLUGIN_DESCRIPTION("Xfer (file transfer and direct chat) plugin for "
"WeeChat");
WEECHAT_PLUGIN_AUTHOR("FlashCode <flashcode@flashtux.org>");
WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
@@ -1105,7 +1105,7 @@ xfer_start_resume_cb (void *data, const char *signal, const char *type_data,
weechat_printf (NULL,
_("%s%s: unable to resume file \"%s\" (port: %d, "
"start position: %lu): xfer not found or not ready "
- "for transfert"),
+ "for transfer"),
weechat_prefix ("error"), XFER_PLUGIN_NAME, filename,
port, start_resume);
}
@@ -1192,7 +1192,7 @@ xfer_accept_resume_cb (void *data, const char *signal, const char *type_data,
weechat_printf (NULL,
_("%s%s: unable to accept resume file \"%s\" (port: %d, "
"start position: %lu): xfer not found or not ready "
- "for transfert"),
+ "for transfer"),
weechat_prefix ("error"), XFER_PLUGIN_NAME, filename,
port, start_resume);
}
@@ -16,7 +16,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-/* xfer.c: file transfert and direct chat plugin for WeeChat */
+/* xfer.c: file transfer and direct chat plugin for WeeChat */
#include <stdlib.h>